@@ -1,4 +1,4 @@
-import os.path
+from os.path import dirname
 
 from pipeline.conf import settings
 from pipeline.compilers import SubProcessCompiler
@@ -10,10 +10,13 @@ class StylusCompiler(SubProcessCompiler):
     def match_file(self, filename):
         return filename.endswith('.styl')
 
-    def compile_file(self, content, path):
-        command = "%s %s" % (
+    def compile_file(self, infile, outfile, outdated=False, force=False):
+        if not outdated and not force:
+            return  # File doesn't need to be recompiled
+        command = "%s %s < %s > %s" % (
             settings.PIPELINE_STYLUS_BINARY,
             settings.PIPELINE_STYLUS_ARGUMENTS,
+            infile,
+            outfile
         )
-        cwd = os.path.dirname(path)
-        return self.execute_command(command, content, cwd=cwd)
+        return self.execute_command(command, cwd=dirname(infile))
