@@ -4,7 +4,7 @@ from pipeline.compressors import SubProcessCompressor
 
 class YUICompressor(SubProcessCompressor):
     def compress_common(self, content, type_, arguments):
-        command = '%s --type=%s %s' % (settings.PIPELINE_YUI_BINARY, type_, arguments)
+        command = '%s --terminal --type=%s %s' % (settings.PIPELINE_YUI_BINARY, type_, arguments)
         return self.execute_command(command, content)
 
     def compress_js(self, js):
